@@ -22,7 +22,7 @@
 [ 17] = { 3,	TN,		SEN(socket),			"socket"		},
 [ 18] = { 2,	TF,		SEN(stat),			"stat"			},
 [ 19] = { 3,	TD,		SEN(lseek),			"lseek"			},
-[ 20] = { 0,	0,		SEN(getpid),			"getpid"		},
+[ 20] = { 0,	NF,		SEN(getpid),			"getpid"		},
 [ 21] = { 5,	TF,		SEN(mount),			"mount"			},
 [ 22] = { 3,	TN,		SEN(bind),			"bind"			},
 [ 23] = { 1,	0,		SEN(setuid),			"setuid"		},
@@ -62,11 +62,11 @@
 [ 57] = { 2,	0,		SEN(setpgid),			"setpgid"		},
 [ 58] = { 4,	TN,		SEN(send),			"send"			},
 [ 59] = { 1,	0,		SEN(uname),			"uname"			},
-[ 60] = { 1,	0,		SEN(umask),			"umask"			},
+[ 60] = { 1,	NF,		SEN(umask),			"umask"			},
 [ 61] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [ 62] = { 2,	0,		SEN(ustat),			"ustat"			},
 [ 63] = { 2,	TD,		SEN(dup2),			"dup2"			},
-[ 64] = { 0,	0,		SEN(getppid),			"getppid"		},
+[ 64] = { 0,	NF,		SEN(getppid),			"getppid"		},
 [ 65] = { 0,	0,		SEN(getpgrp),			"getpgrp"		},
 [ 66] = { 0,	0,		SEN(setsid),			"setsid"		},
 [ 67] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
@@ -130,7 +130,7 @@
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
-[128] = { 4,	0,		SEN(init_module),		"init_module"		},
+[128] = { 3,	0,		SEN(init_module),		"init_module"		},
 [129] = { 2,	0,		SEN(delete_module),		"delete_module"		},
 [130] = { 1,	0,		SEN(get_kernel_syms),		"get_kernel_syms"	},
 [131] = { 4,	TF,		SEN(quotactl),			"quotactl"		},
@@ -138,7 +138,7 @@
 [133] = { 1,	TD,		SEN(fchdir),			"fchdir"		},
 [134] = { 2,	0,		SEN(bdflush),			"bdflush"		},
 [135] = { 3,	0,		SEN(sysfs),			"sysfs"			},
-[136] = { 1,	0,		SEN(personality),		"personality"		},
+[136] = { 1,	NF,		SEN(personality),		"personality"		},
 [137] = { 5,	0,		SEN(afs_syscall),		"afs_syscall"		},
 [138] = { 1,	NF,		SEN(setfsuid),			"setfsuid"		},
 [139] = { 1,	NF,		SEN(setfsgid),			"setfsgid"		},
@@ -155,11 +155,11 @@
 [150] = { 2,	TM,		SEN(mlock),			"mlock"			},
 [151] = { 2,	TM,		SEN(munlock),			"munlock"		},
 [152] = { 1,	TM,		SEN(mlockall),			"mlockall"		},
-[153] = { 1,	TM,		SEN(munlockall),		"munlockall"		},
+[153] = { 0,	TM,		SEN(munlockall),		"munlockall"		},
 [154] = { 2,	0,		SEN(sched_setparam),		"sched_setparam"	},
 [155] = { 2,	0,		SEN(sched_getparam),		"sched_getparam"	},
 [156] = { 3,	0,		SEN(sched_setscheduler),	"sched_setscheduler"	},
-[157] = { 2,	0,		SEN(sched_getscheduler),	"sched_getscheduler"	},
+[157] = { 1,	0,		SEN(sched_getscheduler),	"sched_getscheduler"	},
 [158] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [159] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [160] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
@@ -208,7 +208,7 @@
 [203] = { 5,	0,		SEN(printargs),			"attrctl"		},
 [204] = { 5,	0,		SEN(printargs),			"acl_get"		},
 [205] = { 5,	0,		SEN(printargs),			"acl_set"		},
-[206] = { 0,	0,		SEN(gettid),			"gettid"		},
+[206] = { 0,	NF,		SEN(gettid),			"gettid"		},
 [207] = { 4,	TD,		SEN(readahead),			"readahead"		},
 [208] = { 2,	TS,		SEN(kill),			"tkill"			},
 [209] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
@@ -221,7 +221,7 @@
 [216] = { 1,	0,		SEN(io_destroy),		"io_destroy"		},
 [217] = { 5,	0,		SEN(io_getevents),		"io_getevents"		},
 [218] = { 3,	0,		SEN(io_submit),			"io_submit"		},
-[219] = { 4,	0,		SEN(io_cancel),			"io_cancel"		},
+[219] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
 [220] = { 5,	0,		SEN(printargs),			"alloc_hugepages"	},
 [221] = { 1,	0,		SEN(printargs),			"free_hugepages"	},
 [222] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
@@ -239,19 +239,19 @@
 [234] = { 3,	0,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [235] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [236] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
-[237] = { 5,	0,		SEN(set_tid_address),		"set_tid_address"	},
+[237] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [238] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [239] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [240] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
 [241] = { 4,	TF,		SEN(getxattr),			"getxattr"		},
 [242] = { 4,	TF,		SEN(getxattr),			"lgetxattr"		},
 [243] = { 4,	TD,		SEN(fgetxattr),			"fgetxattr"		},
-[244] = { 5,	TF,		SEN(listxattr),			"listxattr"		},
-[245] = { 5,	TF,		SEN(listxattr),			"llistxattr"		},
-[246] = { 5,	TD,		SEN(flistxattr),		"flistxattr"		},
-[247] = { 5,	TF,		SEN(removexattr),		"removexattr"		},
-[248] = { 5,	TF,		SEN(removexattr),		"lremovexattr"		},
-[249] = { 5,	TD,		SEN(fremovexattr),		"fremovexattr"		},
+[244] = { 3,	TF,		SEN(listxattr),			"listxattr"		},
+[245] = { 3,	TF,		SEN(listxattr),			"llistxattr"		},
+[246] = { 3,	TD,		SEN(flistxattr),		"flistxattr"		},
+[247] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
+[248] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
+[249] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
 [250] = { 3,	0,		SEN(timer_create),		"timer_create"		},
 [251] = { 4,	0,		SEN(timer_settime),		"timer_settime"		},
 [252] = { 2,	0,		SEN(timer_gettime),		"timer_gettime"		},
@@ -348,3 +348,6 @@
 [343] = { 2,	0,		SEN(membarrier),		"membarrier",		},
 [344] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
 [345] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
+[346] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
+[347] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
+[348] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
