@@ -46,7 +46,7 @@
 [ 17] = { 0,	TM,		SEN(break),			"break"			},
 [ 18] = { 2,	TF,		SEN(oldstat),			"oldstat"		},
 [ 19] = { 3,	TD,		SEN(lseek),			"lseek"			},
-[ 20] = { 0,	0,		SEN(getpid),			"getpid"		},
+[ 20] = { 0,	NF,		SEN(getpid),			"getpid"		},
 [ 21] = { 5,	TF,		SEN(mount),			"mount"			},
 [ 22] = { 1,	TF,		SEN(umount),			"umount"		},
 [ 23] = { 1,	0,		SEN(setuid16),			"setuid"		},
@@ -74,7 +74,7 @@
 [ 45] = { 1,	TM|SI,		SEN(brk),			"brk"			},
 [ 46] = { 1,	0,		SEN(setgid16),			"setgid"		},
 [ 47] = { 0,	NF,		SEN(getgid16),			"getgid"		},
-[ 48] = { 3,	TS,		SEN(signal),			"signal"		},
+[ 48] = { 2,	TS,		SEN(signal),			"signal"		},
 [ 49] = { 0,	NF,		SEN(geteuid16),			"geteuid"		},
 [ 50] = { 0,	NF,		SEN(getegid16),			"getegid"		},
 [ 51] = { 1,	TF,		SEN(acct),			"acct"			},
@@ -86,11 +86,11 @@
 [ 57] = { 2,	0,		SEN(setpgid),			"setpgid"		},
 [ 58] = { 2,	0,		SEN(ulimit),			"ulimit"		},
 [ 59] = { 1,	0,		SEN(oldolduname),		"oldolduname"		},
-[ 60] = { 1,	0,		SEN(umask),			"umask"			},
+[ 60] = { 1,	NF,		SEN(umask),			"umask"			},
 [ 61] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [ 62] = { 2,	0,		SEN(ustat),			"ustat"			},
 [ 63] = { 2,	TD,		SEN(dup2),			"dup2"			},
-[ 64] = { 0,	0,		SEN(getppid),			"getppid"		},
+[ 64] = { 0,	NF,		SEN(getppid),			"getppid"		},
 [ 65] = { 0,	0,		SEN(getpgrp),			"getpgrp"		},
 [ 66] = { 0,	0,		SEN(setsid),			"setsid"		},
 [ 67] = { 3,	TS,		SEN(sigaction),			"sigaction"		},
@@ -162,7 +162,7 @@
 [133] = { 1,	TD,		SEN(fchdir),			"fchdir"		},
 [134] = { 2,	0,		SEN(bdflush),			"bdflush"		},
 [135] = { 3,	0,		SEN(sysfs),			"sysfs"			},
-[136] = { 1,	0,		SEN(personality),		"personality"		},
+[136] = { 1,	NF,		SEN(personality),		"personality"		},
 [137] = { 5,	0,		SEN(afs_syscall),		"afs_syscall"		},
 [138] = { 1,	NF,		SEN(setfsuid16),		"setfsuid"		},
 [139] = { 1,	NF,		SEN(setfsgid16),		"setfsgid"		},
@@ -246,7 +246,7 @@
 [217] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
 [218 ... 219] = { },
 [220] = { 3,	TD,		SEN(getdents64),		"getdents64"		},
-[221] = { 0,	0,		SEN(gettid),			"gettid"		},
+[221] = { 0,	NF,		SEN(gettid),			"gettid"		},
 [222] = { 2,	TS,		SEN(kill),			"tkill"			},
 [223] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [224] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
@@ -305,7 +305,7 @@
 [277] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [278] = { 5,	0,		SEN(vserver),			"vserver"		},
 [279] = { 5,	0,		SEN(add_key),			"add_key"		},
-[280] = { 5,	0,		SEN(request_key),		"request_key"		},
+[280] = { 4,	0,		SEN(request_key),		"request_key"		},
 [281] = { 5,	0,		SEN(keyctl),			"keyctl"		},
 [282] = { 3,	0,		SEN(ioprio_set),		"ioprio_set"		},
 [283] = { 2,	0,		SEN(ioprio_get),		"ioprio_get"		},
@@ -401,7 +401,9 @@
 [373] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
 [374] = { 2,	0,		SEN(membarrier),		"membarrier",		},
 [375] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
-[376 ... 399] = { },
+[376] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
+[377] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
+[378] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 
 #define SYS_socket_subcall	400
 #include "subcall.h"
