@@ -21,7 +21,7 @@
 [6018] = { 3,	TD,		SEN(readv),			"readv"			},
 [6019] = { 3,	TD,		SEN(writev),			"writev"		},
 [6020] = { 2,	TF,		SEN(access),			"access"		},
-[6021] = { 1,	TD,		SEN(pipe),			"pipe"			},
+[6021] = { 0,	TD,		SEN(pipe),			"pipe"			},
 [6022] = { 5,	TD,		SEN(select),			"_newselect"		},
 [6023] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [6024] = { 5,	TM|SI,		SEN(mremap),			"mremap"		},
@@ -38,7 +38,7 @@
 [6035] = { 2,	0,		SEN(getitimer),			"getitimer"		},
 [6036] = { 3,	0,		SEN(setitimer),			"setitimer"		},
 [6037] = { 1,	0,		SEN(alarm),			"alarm"			},
-[6038] = { 0,	0,		SEN(getpid),			"getpid"		},
+[6038] = { 0,	NF,		SEN(getpid),			"getpid"		},
 [6039] = { 4,	TD|TN,		SEN(sendfile),			"sendfile"		},
 [6040] = { 3,	TN,		SEN(socket),			"socket"		},
 [6041] = { 3,	TN,		SEN(connect),			"connect"		},
@@ -93,7 +93,7 @@
 [6090] = { 3,	TF,		SEN(chown),			"chown"			},
 [6091] = { 3,	TD,		SEN(fchown),			"fchown"		},
 [6092] = { 3,	TF,		SEN(chown),			"lchown"		},
-[6093] = { 1,	0,		SEN(umask),			"umask"			},
+[6093] = { 1,	NF,		SEN(umask),			"umask"			},
 [6094] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
 [6095] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [6096] = { 2,	0,		SEN(getrusage),			"getrusage"		},
@@ -108,7 +108,7 @@
 [6105] = { 0,	NF,		SEN(geteuid),			"geteuid"		},
 [6106] = { 0,	NF,		SEN(getegid),			"getegid"		},
 [6107] = { 2,	0,		SEN(setpgid),			"setpgid"		},
-[6108] = { 0,	0,		SEN(getppid),			"getppid"		},
+[6108] = { 0,	NF,		SEN(getppid),			"getppid"		},
 [6109] = { 0,	0,		SEN(getpgrp),			"getpgrp"		},
 [6110] = { 0,	0,		SEN(setsid),			"setsid"		},
 [6111] = { 2,	0,		SEN(setreuid),			"setreuid"		},
@@ -119,7 +119,7 @@
 [6116] = { 3,	0,		SEN(getresuid),			"getresuid"		},
 [6117] = { 3,	0,		SEN(setresgid),			"setresgid"		},
 [6118] = { 3,	0,		SEN(getresgid),			"getresgid"		},
-[6119] = { 0,	0,		SEN(getpgid),			"getpgid"		},
+[6119] = { 1,	0,		SEN(getpgid),			"getpgid"		},
 [6120] = { 1,	NF,		SEN(setfsuid),			"setfsuid"		},
 [6121] = { 1,	NF,		SEN(setfsgid),			"setfsgid"		},
 [6122] = { 1,	0,		SEN(getsid),			"getsid"		},
@@ -132,10 +132,10 @@
 [6129] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [6130] = { 2,	TF,		SEN(utime),			"utime"			},
 [6131] = { 3,	TF,		SEN(mknod),			"mknod"			},
-[6132] = { 1,	0,		SEN(personality),		"personality"		},
+[6132] = { 1,	NF,		SEN(personality),		"personality"		},
 [6133] = { 2,	0,		SEN(ustat),			"ustat"			},
-[6134] = { 3,	TF,		SEN(statfs),			"statfs"		},
-[6135] = { 3,	TD,		SEN(fstatfs),			"fstatfs"		},
+[6134] = { 2,	TF,		SEN(statfs),			"statfs"		},
+[6135] = { 2,	TD,		SEN(fstatfs),			"fstatfs"		},
 [6136] = { 3,	0,		SEN(sysfs),			"sysfs"			},
 [6137] = { 2,	0,		SEN(getpriority),		"getpriority"		},
 [6138] = { 3,	0,		SEN(setpriority),		"setpriority"		},
@@ -168,8 +168,8 @@
 [6165] = { 2,	0,		SEN(sethostname),		"sethostname"		},
 [6166] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [6167] = { 2,	0,		SEN(create_module),		"create_module"		},
-[6168] = { 4,	0,		SEN(init_module),		"init_module"		},
-[6169] = { 1,	0,		SEN(delete_module),		"delete_module"		},
+[6168] = { 3,	0,		SEN(init_module),		"init_module"		},
+[6169] = { 2,	0,		SEN(delete_module),		"delete_module"		},
 [6170] = { 1,	0,		SEN(get_kernel_syms),		"get_kernel_syms"	},
 [6171] = { 5,	0,		SEN(query_module),		"query_module"		},
 [6172] = { 4,	TF,		SEN(quotactl),			"quotactl"		},
@@ -178,7 +178,7 @@
 [6175] = { 5,	TN,		SEN(putpmsg),			"putpmsg"		},
 [6176] = { 0,	0,		SEN(afs_syscall),		"afs_syscall"		},
 [6177] = { 0,	0,		SEN(printargs),			"reserved177"		},
-[6178] = { 0,	0,		SEN(gettid),			"gettid"		},
+[6178] = { 0,	NF,		SEN(gettid),			"gettid"		},
 [6179] = { 3,	TD,		SEN(readahead),			"readahead"		},
 [6180] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [6181] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
@@ -324,7 +324,9 @@
 [6321] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
 [6322] = { 2,	0,		SEN(membarrier),		"membarrier",		},
 [6323] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
-[6324 ... 6399] = { },
+[6324] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
+[6325] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
+[6326] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 
 # define SYS_socket_subcall      6400
 # include "subcall.h"
