@@ -18,13 +18,13 @@
 [ 17] = { 1,	TM|SI,		SEN(brk),			"brk"			},
 [ 18] = { 4,	0,		SEN(printargs),			"perfctr"		},
 [ 19] = { 3,	TD,		SEN(lseek),			"lseek"			},
-[ 20] = { 0,	0,		SEN(getpid),			"getpid"		},
+[ 20] = { 0,	NF,		SEN(getpid),			"getpid"		},
 [ 21] = { 2,	0,		SEN(capget),			"capget"		},
 [ 22] = { 2,	0,		SEN(capset),			"capset"		},
 [ 23] = { 1,	0,		SEN(setuid16),			"setuid"		},
 [ 24] = { 0,	NF,		SEN(getuid16),			"getuid"		},
 [ 25] = { 4,	TD,		SEN(vmsplice),			"vmsplice"		},
-[ 26] = { 5,	0,		SEN(ptrace),			"ptrace"		},
+[ 26] = { 4,	0,		SEN(ptrace),			"ptrace"		},
 [ 27] = { 1,	0,		SEN(alarm),			"alarm"			},
 [ 28] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [ 29] = { 0,	TS,		SEN(pause),			"pause"			},
@@ -39,18 +39,18 @@
 [ 38] = { 2,	TF,		SEN(stat),			"stat"			},
 [ 39] = { 4,	TD|TN,		SEN(sendfile),			"sendfile"		},
 [ 40] = { 2,	TF,		SEN(lstat),			"lstat"			},
-[ 41] = { 2,	TD,		SEN(dup),			"dup"			},
+[ 41] = { 1,	TD,		SEN(dup),			"dup"			},
 [ 42] = { 0,	TD,		SEN(pipe),			"pipe"			},
 [ 43] = { 1,	0,		SEN(times),			"times"			},
 [ 44] = { 0,	NF,		SEN(getuid),			"getuid32"		},
 [ 45] = { 2,	TF,		SEN(umount2),			"umount2"		},
 [ 46] = { 1,	0,		SEN(setgid16),			"setgid"		},
 [ 47] = { 0,	NF,		SEN(getgid16),			"getgid"		},
-[ 48] = { 3,	TS,		SEN(signal),			"signal"		},
+[ 48] = { 2,	TS,		SEN(signal),			"signal"		},
 [ 49] = { 0,	NF,		SEN(geteuid16),			"geteuid"		},
 [ 50] = { 0,	NF,		SEN(getegid16),			"getegid"		},
 [ 51] = { 1,	TF,		SEN(acct),			"acct"			},
-[ 52] = { 2,	0,		SEN(printargs),			"memory_ordering"	},
+[ 52] = { },
 [ 53] = { 0,	NF,		SEN(getgid),			"getgid32"		},
 [ 54] = { 3,	TD,		SEN(ioctl),			"ioctl"			},
 [ 55] = { 4,	0,		SEN(reboot),			"reboot"		},
@@ -58,7 +58,7 @@
 [ 57] = { 2,	TF,		SEN(symlink),			"symlink"		},
 [ 58] = { 3,	TF,		SEN(readlink),			"readlink"		},
 [ 59] = { 3,	TF|TP|SE|SI,	SEN(execve),			"execve"		},
-[ 60] = { 1,	0,		SEN(umask),			"umask"			},
+[ 60] = { 1,	NF,		SEN(umask),			"umask"			},
 [ 61] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [ 62] = { 2,	TD,		SEN(fstat),			"fstat"			},
 [ 63] = { 2,	TD,		SEN(fstat64),			"fstat64"		},
@@ -141,7 +141,7 @@
 [140] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [141] = { 3,	TN,		SEN(getpeername),		"getpeername"		},
 [142] = { 6,	0,		SEN(futex),			"futex"			},
-[143] = { 0,	0,		SEN(gettid),			"gettid"		},
+[143] = { 0,	NF,		SEN(gettid),			"gettid"		},
 [144] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [145] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [146] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
@@ -162,7 +162,7 @@
 [161] = { 3,	0,		SEN(sched_getaffinity),		"sched_get_affinity"	},
 [162] = { 2,	0,		SEN(printargs),			"getdomainname"		},
 [163] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
-[164] = { 5,	0,		SEN(printargs),			"utrap_install"		},
+[164] = { },
 [165] = { 4,	TF,		SEN(quotactl),			"quotactl"		},
 [166] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [167] = { 5,	TF,		SEN(mount),			"mount"			},
@@ -189,13 +189,13 @@
 [188] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [189] = { 1,	0,		SEN(uname),			"uname"			},
 [190] = { 3,	0,		SEN(init_module),		"init_module"		},
-[191] = { 1,	0,		SEN(personality),		"personality"		},
+[191] = { 1,	NF,		SEN(personality),		"personality"		},
 [192] = { 5,	TM|SI,		SEN(remap_file_pages),		"remap_file_pages"	},
 [193] = { 1,	TD,		SEN(epoll_create),		"epoll_create"		},
 [194] = { 4,	TD,		SEN(epoll_ctl),			"epoll_ctl"		},
 [195] = { 4,	TD,		SEN(epoll_wait),		"epoll_wait"		},
 [196] = { 3,	0,		SEN(ioprio_set),		"ioprio_set"		},
-[197] = { 0,	0,		SEN(getppid),			"getppid"		},
+[197] = { 0,	NF,		SEN(getppid),			"getppid"		},
 [198] = { 3,	TS,		SEN(sigaction),			"sigaction"		},
 [199] = { 0,	TS,		SEN(siggetmask),		"sgetmask"		},
 [200] = { 1,	TS,		SEN(sigsetmask),		"ssetmask"		},
@@ -213,7 +213,7 @@
 [212] = { 3,	TP,		SEN(waitpid),			"waitpid"		},
 [213] = { 1,	TF,		SEN(swapoff),			"swapoff"		},
 [214] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
-[215] = { 5,	TI,		SEN(ipc),			"ipc"			},
+[215] = { 6,	TI,		SEN(ipc),			"ipc"			},
 [216] = { 0,	TS,		SEN(sigreturn),			"sigreturn"		},
 [217] = { 5,	TP,		SEN(clone),			"clone"			},
 [218] = { 2,	0,		SEN(ioprio_get),		"ioprio_get"		},
@@ -351,8 +351,13 @@
 [350] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
 [351] = { 2,	0,		SEN(membarrier),		"membarrier",		},
 [352] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[353] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
-[354 ... 399] = { },
+[353] = { 3,	TN,		SEN(bind),			"bind"			},
+[354] = { 2,	TN,		SEN(listen),			"listen"		},
+[355] = { 5,	TN,		SEN(setsockopt),		"setsockopt"		},
+[356] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
+[357] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
+[358] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
+[359] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 
 #define SYS_socket_subcall	400
 #include "subcall.h"
